@@ -9,11 +9,11 @@ import alphaconf.invoke
 def doit(ctx, param=None):
     logging.info('Hello')
     # get the default configuration
-    logging.info('Backup: %s', alphaconf.configuration().backup)
+    logging.info('Backup: %s', alphaconf.configuration.get().backup)
     # if we have a parameter, let's run some code within a context
     # where we use this parameter in the configuration
     if param:
-        with alphaconf.application.get().update_configuration({'param': param}):
+        with alphaconf.set(param=param):
             logging.info('Param: [%s] and in alphaconf [%s]', param, alphaconf.get('param'))
     else:
         logging.warning('No parameter')
@@ -22,4 +22,4 @@ def doit(ctx, param=None):
 # add some default configuration and run/configure invoke's namespace
 ns = Collection(doit)
 alphaconf.setup_configuration({'backup': 'all'})
-alphaconf.invoke.invoke_application(__name__, ns)
+alphaconf.invoke.run(__name__, ns)
